@@ -322,17 +322,9 @@ bool MainWindow::openFile(const QUrl& url, const QUrl& startUrl)
     worldModel->clearWorld();
     newFile();
 
-    QTemporaryFile tempFile;
-    tempFile.open();
-    KIO::FileCopyJob *job = KIO::file_copy(url, QUrl::fromLocalFile(tempFile.fileName()), -1, KIO::Overwrite);
-    KJobWidgets::setWindow(job, this);
-    job->exec();
-    if (job->error()) {
-        KMessageBox::error(this, job->errorString());
-        return false;
-    }
+    QFile file(fileUrl.path());
     
-    if(!worldModel->loadXml(&tempFile)) {
+    if(!worldModel->loadXml(&file)) {
         KMessageBox::sorry(this, i18n("Cannot parse file '%1': %2", fileUrl.url(QUrl::PreferLocalFile),
                                                     worldModel->errorString()));
         return false;
@@ -355,18 +347,7 @@ bool MainWindow::saveFileAs(const QUrl& url, const QUrl& startUrl)
     if(fileUrl.isEmpty()) {
         fileUrl = QFileDialog::getSaveFileUrl(this, i18n("Save Step File"), startUrl.isEmpty() ? currentFileUrl : startUrl, i18n("Step files (*.step)"));
         if(fileUrl.isEmpty()) return false;
-        else {
-            KIO::StatJob* statJob = KIO::stat(fileUrl, KIO::StatJob::DestinationSide, 0);
-            KJobWidgets::setWindow(statJob, this);
-            if (statJob->exec()) {
-            int ret = KMessageBox::warningContinueCancel(this,
-                        i18n("The file \"%1\" already exists. Do you wish to overwrite it?",
-			     fileUrl.url(QUrl::PreferLocalFile)),
-                        i18n("Warning - Step"), KStandardGuiItem::overwrite());
-            if(ret != KMessageBox::Continue) return false;
-            }
         }
-    }
 
     bool local = fileUrl.isLocalFile();
     QFile* file;
